==> nenupy-0.5.4.tar.gz: nenupy-0.5.4/nenupy/beam/antenna/miniarrays.py <==
#! /usr/bin/python3.5
# -*- coding: utf-8 -*-

"""
Mini-array measurements from (https://confluence2.obs-nancay.fr/pages/viewpage.action?pageId=3997697&preview=/3997697/11600353/Coordonnees_MR00-MR51_20180613_LD.xls)
        by A. Loh
"""

import numpy as np

from astropy import units as u
from astropy import coordinates as coord

__author__ = 'Alan Loh'
__copyright__ = 'Copyright 2018, nenupy'
__credits__ = ['Alan Loh']
__license__ = 'MIT'
__version__ = '0.0.1'
__maintainer__ = 'Alan Loh'
__email__ = 'alan.loh@obspm.fr'
__status__ = 'WIP'
__all__ = ['antpos', 'ma', 'all_ma', 'nenufarloc']


nenufarloc = coord.EarthLocation(lat=47.376511*u.deg, lon=2.1924002*u.deg)

antpos = np.array([
    -5.50000000e+00, -9.52627850e+00,  0.00000000e+00,
     0.00000000e+00, -9.52627850e+00,  0.00000000e+00,
     5.50000000e+00, -9.52627850e+00,  0.00000000e+00,
    -8.25000000e+00, -4.76313877e+00,  0.00000000e+00,
    -2.75000000e+00, -4.76313877e+00,  0.00000000e+00,
     2.75000000e+00, -4.76313877e+00,  0.00000000e+00,
     8.25000000e+00, -4.76313877e+00,  0.00000000e+00,
    -1.10000000e+01,  9.53674316e-07,  0.00000000e+00,
    -5.50000000e+00,  9.53674316e-07,  0.00000000e+00,
     0.00000000e+00,  9.53674316e-07,  0.00000000e+00,
     5.50000000e+00,  9.53674316e-07,  0.00000000e+00,
     1.10000000e+01,  9.53674316e-07,  0.00000000e+00,
    -8.25000000e+00,  4.76314068e+00,  0.00000000e+00,
    -2.75000000e+00,  4.76314068e+00,  0.00000000e+00,
     2.75000000e+00,  4.76314068e+00,  0.00000000e+00,
     8.25000000e+00,  4.76314068e+00,  0.00000000e+00,
    -5.50000000e+00,  9.52628040e+00,  0.00000000e+00,
     0.00000000e+00,  9.52628040e+00,  0.00000000e+00,
     5.50000000e+00,  9.52628040e+00,  0.00000000e+00
    ]).reshape(19, 3)


# noMA, rot, pos_x (L93 measured), pos_y, pos_z, delay (ns), att (dB) 
ma = np.array([
    [0 , 0  , 639113.316, 6697663.473, 181.735, 440.5 , 29.5],
    [1 , 30 , 639094.578, 6697644.715, 181.750, 364   , 30  ],
    [2 , 300, 639069.472, 6697634.429, 181.761, 150   , 31  ],
    [3 , 200, 639038.120, 6697619.754, 181.757, 145.5 , 31  ],
    [4 , 20 , 639020.122, 6697598.922, 181.762, 464.5 , 28.5],
    [5 , 180, 639062.298, 6697659.113, 181.671, 384.5 , 30  ],
    [6 , 180, 639039.218, 6697646.381, 181.718, 276.5 , 31  ],
    [7 , 230, 638985.155, 6697627.952, 181.620, 471   , 28.5],
    [8 , 150, 639002.711, 6697647.883, 181.677, 411.5 , 29.5],
    [9 , 240, 639006.567, 6697674.708, 181.737, 428.5 , 29.5],
    [10, 290, 639033.717, 6697697.363, 181.762, 496   , 28.5],
    [11, 310, 639040.955, 6697728.209, 181.813, 663   , 27.5],
    [12, 250, 639061.482, 6697709.858, 181.727, 659.5 , 25  ],
    [13, 40 , 639081.586, 6697747.997, 181.997, 958   , 24.5],
    [14, 330, 639099.636, 6697780.199, 182.152, 1032  , 24.5],
    [15, 280, 639098.493, 6697726.359, 181.912, 793   , 26.5],
    [16, 60 , 639128.375, 6697745.064, 182.005, 1054.5, 24  ],
    [17, 110, 639153.064, 6697760.961, 182.062, 1233  , 23  ],
    [18, 10 , 639201.475, 6697767.744, 182.083, 1355  , 22  ],
    [19, 210, 639146.673, 6697790.436, 182.199, 1249.5, 22.5],
    [20, 320, 639191.912, 6697807.839, 182.057, 1352.5, 21.5],
    [21, 260, 639158.373, 6697844.968, 182.201, 1461  , 21.5],
    [22, 250, 639007.359, 6697734.730, 181.967, 662   , 27.5],
    [23, 170, 638994.637, 6697780.061, 182.016, 969.5 , 25  ],
    [24, 180, 638974.900, 6697797.705, 182.057, 1082.5, 24.5],
    [25, 50 , 639039.664, 6697796.029, 182.092, 1052  , 23.5],
    [26, 300, 639051.439, 6697828.330, 182.133, 1112  , 23.5],
    [27, 210, 639037.314, 6697862.392, 182.535, 1387  , 21  ],
    [28, 320, 639106.516, 6697880.517, 182.416, 1527.5, 20.5],
    [29, 330, 639085.345, 6697826.937, 182.164, 1226  , 22  ],
    [30, 60 , 639124.407, 6697813.619, 182.277, 1530.5, 20.5],
    [31, 20 , 639118.439, 6697846.786, 182.334, 1462  , 21  ],
    [32, 290, 638980.493, 6697661.622, 181.773, 573   , 28  ],
    [33, 240, 638955.067, 6697653.896, 181.787, 616.5 , 27.5],
    [34, 230, 638917.110, 6697642.462, 181.723, 770.5 , 26  ],
    [35, 340, 638901.511, 6697665.620, 181.722, 1024  , 24.5],
    [36, 170, 638842.551, 6697684.224, 181.915, 1182.5, 23  ],
    [37, 350, 638881.893, 6697706.134, 181.971, 1231  , 23  ],
    [38, 260, 638828.310, 6697731.499, 182.165, 1365  , 21.5],
    [39, 160, 638798.998, 6697676.964, 182.180, 1472  , 21  ],
    [40, 220, 638828.026, 6697644.185, 182.034, 1115.5, 24  ],
    [41, 120, 638994.603, 6697699.384, 181.819, 661.5 , 26.5],
    [42, 140, 638973.994, 6697731.272, 181.940, 802.5 , 25.5],
    [43, 130, 638963.888, 6697756.816, 182.315, 932   , 24.5],
    [44, 110, 638907.143, 6697757.070, 182.406, 1187  , 23  ],
    [45, 150, 638934.310, 6697762.760, 182.306, 1030  , 23.5],
    [46, 300, 638947.300, 6697795.415, 182.257, 1096  , 23.5],
    [47, 190, 638957.218, 6697683.457, 181.905, 721.5 , 26.5],
    [48, 100, 638932.724, 6697691.062, 181.967, 898   , 26  ],
    [49, 340, 638924.357, 6697729.083, 182.312, 1029  , 23.5],
    [50, 160, 638865.831, 6697782.977, 182.415, 1339.5, 23  ],
    [51, 240, 638881.847, 6697760.090, 182.376, 1138.5, 23.5],
    [52, 270, 639169.242, 6697692.473, 182.376, 1014,   23.5],
    [53, 340, 639199.806, 6697682.86,  182.376, 1014,   23.5],
    [54, 310, 639223.589, 6697708.094, 182.376, 1106,   23.5],
    [55, 90,  639216.821, 6697651.656, 182.376, 1106,   23.5]
])

# All planned Mini-Arrays
all_ma = np.array([[639113.347, 6697663.522, 0.0],
                   [639094.592, 6697644.758, 0.0],
                   [639039.214, 6697646.506, 0.0],
                   [639038.166, 6697619.83,  0.0],
                   [639062.331, 6697659.118, 0.0],
                   [639069.49,  6697634.455, 0.0],
                   [639020.18,  6697598.92,  0.0],
                   [638985.156, 6697627.949, 0.0],
                   [639002.748, 6697647.878, 0.0],
                   [639006.591, 6697674.656, 0.0],
                   [639033.722, 6697697.346, 0.0],
                   [639061.472, 6697709.873, 0.0],
                   [639098.519, 6697726.227, 0.0],
                   [639081.618, 6697747.939, 0.0],
                   [639040.962, 6697728.207, 0.0],
                   [639007.397, 6697734.665, 0.0],
                   [638994.558, 6697699.406, 0.0],
                   [638980.554, 6697661.59,  0.0],
                   [638955.094, 6697653.882, 0.0],
                   [638973.984, 6697731.255, 0.0],
                   [638957.184, 6697683.464, 0.0],
                   [638932.724, 6697691.066, 0.0],
                   [638924.393, 6697729.101, 0.0],
                   [638865.872, 6697782.955, 0.0],
                   [638881.868, 6697760.114, 0.0],
                   [638907.187, 6697757.084, 0.0],
                   [638934.324, 6697762.737, 0.0],
                   [638947.321, 6697795.411, 0.0],
                   [638974.93,  6697797.715, 0.0],
                   [638963.819, 6697756.819, 0.0],
                   [638994.651, 6697780.023, 0.0],
                   [639039.642, 6697796.01,  0.0],
                   [639037.293, 6697862.361, 0.0],
                   [639051.489, 6697828.37,  0.0],
                   [639085.384, 6697826.925, 0.0],
                   [639106.544, 6697880.47,  0.0],
                   [639124.452, 6697813.584, 0.0],
                   [639118.467, 6697846.77,  0.0],
                   [639099.636, 6697780.171, 0.0],
                   [639146.759, 6697790.361, 0.0],
                   [639128.433, 6697745.04,  0.0],
                   [639153.161, 6697760.929, 0.0],
                   [639201.617, 6697767.749, 0.0],
                   [639192.014, 6697807.847, 0.0],
                   [639158.425, 6697844.973, 0.0],
                   [638917.185, 6697642.473, 0.0],
                   [638901.527, 6697665.648, 0.0],
                   [638881.891, 6697706.167, 0.0],
                   [638828.315, 6697731.488, 0.0],
                   [638842.565, 6697684.193, 0.0],
                   [638828.061, 6697644.181, 0.0],
                   [638798.977, 6697676.94,  0.0],
                   [638958.297, 6697597.123, 0.0],
                   [638821.406, 6697535.222, 0.0],
                   [638863.828, 6697563.352, 0.0],
                   [638925.577, 6697597.423, 0.0],
                   [638845.192, 6697494.023, 0.0],
                   [638900.689, 6697548.702, 0.0],
                   [638834.766, 6697584.586, 0.0],
                   [638797.527, 6697595.073, 0.0],
                   [638979.155, 6697569.794, 0.0],
                   [638889.329, 6697460.317, 0.0],
                   [638903.005, 6697486.944, 0.0],
                   [638938.356, 6697535.795, 0.0],
                   [638924.86,  6697452.963, 0.0],
                   [638951.337, 6697490.678, 0.0],
                   [638970.06,  6697540.611, 0.0],
                   [638997.175, 6697545.42,  0.0],
                   [639004.277, 6697518.766, 0.0],
                   [638987.518, 6697461.71,  0.0],
                   [639027.75,  6697502.422, 0.0],
                   [639042.365, 6697460.184, 0.0],
                   [639169.235, 6697692.481, 0.0],
                   [639223.555, 6697708.067, 0.0],
                   [639166.473, 6697659.062, 0.0],
                   [639199.791, 6697682.877, 0.0],
                   [639183.46,  6697635.465, 0.0],
                   [639216.789, 6697651.688, 0.0],
                   [639215.37,  6697624.2,   0.0],
                   [639212.491, 6697596.795, 0.0],
                   [639081.582, 6697491.262, 0.0],
                   [639114.399, 6697512.754, 0.0],
                   [639194.4,   6697570.617, 0.0],
                   [639149.278, 6697538.022, 0.0],
                   [639172.075, 6697554.414, 0.0],
                   [639195.301, 6697539.289, 0.0],
                   [639046.267, 6697413.41,  0.0],
                   [639010.447, 6697381.984, 0.0],
                   [639049.345, 6697373.625, 0.0],
                   [639084.133, 6697372.451, 0.0],
                   [639120.22,  6697452.36,  0.0],
                   [639148.719, 6697480.267, 0.0],
                   [639137.18,  6697387.014, 0.0],
                   [639158.085, 6697404.914, 0.0],
                   [639199.446, 6697454.725, 0.0],
                   [639213.387, 6697485.127, 0.0]])

==> nenupy-0.5.5.tar.gz: nenupy-0.5.5/nenupy/beam/antenna/miniarrays.py <==
#! /usr/bin/python3.5
# -*- coding: utf-8 -*-

"""
Mini-array measurements from (https://confluence2.obs-nancay.fr/pages/viewpage.action?pageId=3997697&preview=/3997697/11600353/Coordonnees_MR00-MR51_20180613_LD.xls)
        by A. Loh
"""

import numpy as np

from astropy import units as u
from astropy import coordinates as coord

__author__ = 'Alan Loh'
__copyright__ = 'Copyright 2018, nenupy'
__credits__ = ['Alan Loh']
__license__ = 'MIT'
__version__ = '0.0.1'
__maintainer__ = 'Alan Loh'
__email__ = 'alan.loh@obspm.fr'
__status__ = 'WIP'
__all__ = ['antpos', 'ma', 'all_ma', 'all_remote', 'ma_petal', 'nenufarloc']


nenufarloc = coord.EarthLocation(lat=47.376511*u.deg, lon=2.1924002*u.deg)

antpos = np.array([
    -5.50000000e+00, -9.52627850e+00,  0.00000000e+00,
     0.00000000e+00, -9.52627850e+00,  0.00000000e+00,
     5.50000000e+00, -9.52627850e+00,  0.00000000e+00,
    -8.25000000e+00, -4.76313877e+00,  0.00000000e+00,
    -2.75000000e+00, -4.76313877e+00,  0.00000000e+00,
     2.75000000e+00, -4.76313877e+00,  0.00000000e+00,
     8.25000000e+00, -4.76313877e+00,  0.00000000e+00,
    -1.10000000e+01,  9.53674316e-07,  0.00000000e+00,
    -5.50000000e+00,  9.53674316e-07,  0.00000000e+00,
     0.00000000e+00,  9.53674316e-07,  0.00000000e+00,
     5.50000000e+00,  9.53674316e-07,  0.00000000e+00,
     1.10000000e+01,  9.53674316e-07,  0.00000000e+00,
    -8.25000000e+00,  4.76314068e+00,  0.00000000e+00,
    -2.75000000e+00,  4.76314068e+00,  0.00000000e+00,
     2.75000000e+00,  4.76314068e+00,  0.00000000e+00,
     8.25000000e+00,  4.76314068e+00,  0.00000000e+00,
    -5.50000000e+00,  9.52628040e+00,  0.00000000e+00,
     0.00000000e+00,  9.52628040e+00,  0.00000000e+00,
     5.50000000e+00,  9.52628040e+00,  0.00000000e+00
    ]).reshape(19, 3)


# noMA, rot, pos_x (L93 measured), pos_y, pos_z, delay (ns), att (dB) 
ma = np.array([
    [0 , 0  , 639113.316, 6697663.473, 181.735, 440.5 , 29.5],
    [1 , 30 , 639094.578, 6697644.715, 181.750, 364   , 30  ],
    [2 , 300, 639069.472, 6697634.429, 181.761, 150   , 31  ],
    [3 , 200, 639038.120, 6697619.754, 181.757, 145.5 , 31  ],
    [4 , 20 , 639020.122, 6697598.922, 181.762, 464.5 , 28.5],
    [5 , 180, 639062.298, 6697659.113, 181.671, 384.5 , 30  ],
    [6 , 180, 639039.218, 6697646.381, 181.718, 276.5 , 31  ],
    [7 , 230, 638985.155, 6697627.952, 181.620, 471   , 28.5],
    [8 , 150, 639002.711, 6697647.883, 181.677, 411.5 , 29.5],
    [9 , 240, 639006.567, 6697674.708, 181.737, 428.5 , 29.5],
    [10, 290, 639033.717, 6697697.363, 181.762, 496   , 28.5],
    [11, 310, 639040.955, 6697728.209, 181.813, 663   , 27.5],
    [12, 250, 639061.482, 6697709.858, 181.727, 659.5 , 25  ],
    [13, 40 , 639081.586, 6697747.997, 181.997, 958   , 24.5],
    [14, 330, 639099.636, 6697780.199, 182.152, 1032  , 24.5],
    [15, 280, 639098.493, 6697726.359, 181.912, 793   , 26.5],
    [16, 60 , 639128.375, 6697745.064, 182.005, 1054.5, 24  ],
    [17, 110, 639153.064, 6697760.961, 182.062, 1233  , 23  ],
    [18, 10 , 639201.475, 6697767.744, 182.083, 1355  , 22  ],
    [19, 210, 639146.673, 6697790.436, 182.199, 1249.5, 22.5],
    [20, 320, 639191.912, 6697807.839, 182.057, 1352.5, 21.5],
    [21, 260, 639158.373, 6697844.968, 182.201, 1461  , 21.5],
    [22, 250, 639007.359, 6697734.730, 181.967, 662   , 27.5],
    [23, 170, 638994.637, 6697780.061, 182.016, 969.5 , 25  ],
    [24, 180, 638974.900, 6697797.705, 182.057, 1082.5, 24.5],
    [25, 50 , 639039.664, 6697796.029, 182.092, 1052  , 23.5],
    [26, 300, 639051.439, 6697828.330, 182.133, 1112  , 23.5],
    [27, 210, 639037.314, 6697862.392, 182.535, 1387  , 21  ],
    [28, 320, 639106.516, 6697880.517, 182.416, 1527.5, 20.5],
    [29, 330, 639085.345, 6697826.937, 182.164, 1226  , 22  ],
    [30, 60 , 639124.407, 6697813.619, 182.277, 1530.5, 20.5],
    [31, 20 , 639118.439, 6697846.786, 182.334, 1462  , 21  ],
    [32, 290, 638980.493, 6697661.622, 181.773, 573   , 28  ],
    [33, 240, 638955.067, 6697653.896, 181.787, 616.5 , 27.5],
    [34, 230, 638917.110, 6697642.462, 181.723, 770.5 , 26  ],
    [35, 340, 638901.511, 6697665.620, 181.722, 1024  , 24.5],
    [36, 170, 638842.551, 6697684.224, 181.915, 1182.5, 23  ],
    [37, 350, 638881.893, 6697706.134, 181.971, 1231  , 23  ],
    [38, 260, 638828.310, 6697731.499, 182.165, 1365  , 21.5],
    [39, 160, 638798.998, 6697676.964, 182.180, 1472  , 21  ],
    [40, 220, 638828.026, 6697644.185, 182.034, 1115.5, 24  ],
    [41, 120, 638994.603, 6697699.384, 181.819, 661.5 , 26.5],
    [42, 140, 638973.994, 6697731.272, 181.940, 802.5 , 25.5],
    [43, 130, 638963.888, 6697756.816, 182.315, 932   , 24.5],
    [44, 110, 638907.143, 6697757.070, 182.406, 1187  , 23  ],
    [45, 150, 638934.310, 6697762.760, 182.306, 1030  , 23.5],
    [46, 300, 638947.300, 6697795.415, 182.257, 1096  , 23.5],
    [47, 190, 638957.218, 6697683.457, 181.905, 721.5 , 26.5],
    [48, 100, 638932.724, 6697691.062, 181.967, 898   , 26  ],
    [49, 340, 638924.357, 6697729.083, 182.312, 1029  , 23.5],
    [50, 160, 638865.831, 6697782.977, 182.415, 1339.5, 23  ],
    [51, 240, 638881.847, 6697760.090, 182.376, 1138.5, 23.5],
    [52, 270, 639169.242, 6697692.473, 182.376, 1014,   23.5],
    [53, 340, 639199.806, 6697682.86,  182.376, 1014,   23.5],
    [54, 310, 639223.589, 6697708.094, 182.376, 1106,   23.5],
    [55, 90,  639216.821, 6697651.656, 182.376, 1106,   23.5]
])

# All planned Mini-Arrays (they are not indexed as MA indices)
all_ma = np.array([[639113.347, 6697663.522, 0.0],
                   [639094.592, 6697644.758, 0.0],
                   [639039.214, 6697646.506, 0.0],
                   [639038.166, 6697619.83,  0.0],
                   [639062.331, 6697659.118, 0.0],
                   [639069.49,  6697634.455, 0.0],
                   [639020.18,  6697598.92,  0.0],
                   [638985.156, 6697627.949, 0.0],
                   [639002.748, 6697647.878, 0.0],
                   [639006.591, 6697674.656, 0.0],
                   [639033.722, 6697697.346, 0.0],
                   [639061.472, 6697709.873, 0.0],
                   [639098.519, 6697726.227, 0.0],
                   [639081.618, 6697747.939, 0.0],
                   [639040.962, 6697728.207, 0.0],
                   [639007.397, 6697734.665, 0.0],
                   [638994.558, 6697699.406, 0.0],
                   [638980.554, 6697661.59,  0.0],
                   [638955.094, 6697653.882, 0.0],
                   [638973.984, 6697731.255, 0.0],
                   [638957.184, 6697683.464, 0.0],
                   [638932.724, 6697691.066, 0.0],
                   [638924.393, 6697729.101, 0.0],
                   [638865.872, 6697782.955, 0.0],
                   [638881.868, 6697760.114, 0.0],
                   [638907.187, 6697757.084, 0.0],
                   [638934.324, 6697762.737, 0.0],
                   [638947.321, 6697795.411, 0.0],
                   [638974.93,  6697797.715, 0.0],
                   [638963.819, 6697756.819, 0.0],
                   [638994.651, 6697780.023, 0.0],
                   [639039.642, 6697796.01,  0.0],
                   [639037.293, 6697862.361, 0.0],
                   [639051.489, 6697828.37,  0.0],
                   [639085.384, 6697826.925, 0.0],
                   [639106.544, 6697880.47,  0.0],
                   [639124.452, 6697813.584, 0.0],
                   [639118.467, 6697846.77,  0.0],
                   [639099.636, 6697780.171, 0.0],
                   [639146.759, 6697790.361, 0.0],
                   [639128.433, 6697745.04,  0.0],
                   [639153.161, 6697760.929, 0.0],
                   [639201.617, 6697767.749, 0.0],
                   [639192.014, 6697807.847, 0.0],
                   [639158.425, 6697844.973, 0.0],
                   [638917.185, 6697642.473, 0.0],
                   [638901.527, 6697665.648, 0.0],
                   [638881.891, 6697706.167, 0.0],
                   [638828.315, 6697731.488, 0.0],
                   [638842.565, 6697684.193, 0.0],
                   [638828.061, 6697644.181, 0.0],
                   [638798.977, 6697676.94,  0.0],
                   [638958.297, 6697597.123, 0.0],
                   [638821.406, 6697535.222, 0.0],
                   [638863.828, 6697563.352, 0.0],
                   [638925.577, 6697597.423, 0.0],
                   [638845.192, 6697494.023, 0.0],
                   [638900.689, 6697548.702, 0.0],
                   [638834.766, 6697584.586, 0.0],
                   [638797.527, 6697595.073, 0.0],
                   [638979.155, 6697569.794, 0.0],
                   [638889.329, 6697460.317, 0.0],
                   [638903.005, 6697486.944, 0.0],
                   [638938.356, 6697535.795, 0.0],
                   [638924.86,  6697452.963, 0.0],
                   [638951.337, 6697490.678, 0.0],
                   [638970.06,  6697540.611, 0.0],
                   [638997.175, 6697545.42,  0.0],
                   [639004.277, 6697518.766, 0.0],
                   [638987.518, 6697461.71,  0.0],
                   [639027.75,  6697502.422, 0.0],
                   [639042.365, 6697460.184, 0.0],
                   [639169.235, 6697692.481, 0.0],
                   [639223.555, 6697708.067, 0.0],
                   [639166.473, 6697659.062, 0.0],
                   [639199.791, 6697682.877, 0.0],
                   [639183.46,  6697635.465, 0.0],
                   [639216.789, 6697651.688, 0.0],
                   [639215.37,  6697624.2,   0.0],
                   [639212.491, 6697596.795, 0.0],
                   [639081.582, 6697491.262, 0.0],
                   [639114.399, 6697512.754, 0.0],
                   [639194.4,   6697570.617, 0.0],
                   [639149.278, 6697538.022, 0.0],
                   [639172.075, 6697554.414, 0.0],
                   [639195.301, 6697539.289, 0.0],
                   [639046.267, 6697413.41,  0.0],
                   [639010.447, 6697381.984, 0.0],
                   [639049.345, 6697373.625, 0.0],
                   [639084.133, 6697372.451, 0.0],
                   [639120.22,  6697452.36,  0.0],
                   [639148.719, 6697480.267, 0.0],
                   [639137.18,  6697387.014, 0.0],
                   [639158.085, 6697404.914, 0.0],
                   [639199.446, 6697454.725, 0.0],
                   [639213.387, 6697485.127, 0.0]])

# Petals
# real MA indices :
ma_petal = {
  'P1': np.array([0, 1, 2, 5, 52, 53, 54, 55]),
  'P2': np.array([10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21]),
  'P3': np.array([22, 23, 24, 25, 26, 27, 28, 29, 30, 31]),
  'P4': np.array([9, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51]),
  'P5': np.array([6, 7, 8, 32, 33, 34, 35, 36, 37, 38, 39, 40]),
  'P6': np.array([3, 4, 56, 57, 58, 59, 60, 61, 62, 63]),
  'P7': np.array([64, 65, 66, 67, 68, 69, 70, 71]),
  'P8': np.array([72, 73, 74, 76, 78, 81, 82, 87, 88, 89, 90, 91, 92, 93, 94]),
  'P9': np.array([75, 77, 79, 80, 83, 84, 85, 86, 95]),
}

# Compatible with `all_ma`
# ma_petal2 = {
#   'P6': np.array([52,53,54,55,56,57,58,59]),
#   'P7': np.array([60,61,62,63,64,65,66,69]),
#   'P8': np.array([67,68,70,71,80,81,86,87,88,89,90,91,92,93]),
#   'P9': np.array([74,76,78,79,82,83,84,85,94,95]),
# }



# All planned remote Mini-Arrays
all_remote = np.array([
      [639592.76, 6697936.983, 184.324]
    ])
